@@ -5,6 +5,16 @@ import apispec_webframeworks.flask
 from ..api import _examples as ex
 from ..config import Config
 
+# `api_server_url` is used for populating the 'Servers' dropdown in the
+# Swagger/OpenAPI docs website. The default value is tailored to the Flask
+# development HTTP server defaults (non-TLS, binds on 127.0.0.1, port 5000).
+# Can be adjusted via the `--host` and `--port` command line flags when
+# invoking `flask run`.
+api_server_url = "http://127.0.0.1:5000/"
+if Config.INTENDED_BASE_URL is not None:
+    api_server_url = Config.INTENDED_BASE_URL
+
+
 spec = apispec.APISpec(
     title=Config.APPLICATION_NAME,
     version="1.0.0",
@@ -13,7 +23,7 @@ spec = apispec.APISpec(
         apispec_webframeworks.flask.FlaskPlugin(),
         apispec.ext.marshmallow.MarshmallowPlugin(),
     ],
-    servers=[{"url": "http://localhost:5000/"}],
+    servers=[{"url": api_server_url}],
 )
 
 
@@ -68,16 +78,17 @@ spec.components.response("CommitEntity", _200_ok(ex.COMMIT_ENTITY))
 spec.components.response("CommitList", _200_ok([ex.COMMIT_ENTITY]))
 spec.components.response("CompareEntity", _200_ok(ex.COMPARE_ENTITY))
 spec.components.response("CompareList", _200_ok(ex.COMPARE_LIST))
-spec.components.response("CompareSummary", _200_ok(ex.COMPARE_SUMMARY))
+spec.components.response("CompareBenchmarkResult", _200_ok(ex.COMPARE_BENCHMARK_RESULT))
 spec.components.response("ContextEntity", _200_ok(ex.CONTEXT_ENTITY))
 spec.components.response("ContextList", _200_ok([ex.CONTEXT_ENTITY]))
 spec.components.response("InfoList", _200_ok([ex.INFO_ENTITY]))
 spec.components.response("HistoryList", _200_ok([ex.HISTORY_ENTITY]))
 spec.components.response("InfoEntity", _200_ok(ex.INFO_ENTITY))
-spec.components.response("MachineEntity", _200_ok(ex.MACHINE_ENTITY))
-spec.components.response("MachineList", _200_ok([ex.MACHINE_ENTITY]))
+spec.components.response("HardwareEntity", _200_ok(ex.HARDWARE_ENTITY))
+spec.components.response("HardwareList", _200_ok([ex.HARDWARE_ENTITY]))
 spec.components.response("RunEntity", _200_ok(ex.RUN_ENTITY))
 spec.components.response("RunList", _200_ok(ex.RUN_LIST))
+spec.components.response("RunCreated", _201_created(ex.RUN_ENTITY))
 spec.components.response("UserEntity", _200_ok(ex.USER_ENTITY))
 spec.components.response("UserList", _200_ok(ex.USER_LIST))
 spec.components.response("UserCreated", _201_created(ex.USER_ENTITY))
@@ -93,7 +104,7 @@ tags = [
     {"name": "Info", "description": "Extra benchmark information"},
     {"name": "Contexts", "description": "Benchmark contexts"},
     {"name": "History", "description": "Benchmark history"},
-    {"name": "Machines", "description": "Benchmark machines"},
+    {"name": "Hardware", "description": "Benchmark hardware"},
     {"name": "Runs", "description": "Benchmark runs"},
     {"name": "Ping", "description": "Monitor status"},
 ]
