@@ -23,59 +23,107 @@ def _api_user_entity(user):
 
 
 def _api_benchmark_entity(
-    summary_id,
+    benchmark_result_id,
     case_id,
     info_id,
     context_id,
     batch_id,
     run_id,
     name,
+    stats=None,
+    error=None,
+    validation=None,
+    optional_benchmark_info=None,
 ):
-    return {
-        "id": summary_id,
-        "run_id": run_id,
-        "batch_id": batch_id,
-        "timestamp": "2020-11-25T21:02:42.706806",
-        "stats": {
-            "data": [
-                "0.099094",
-                "0.037129",
-                "0.036381",
-                "0.148896",
-                "0.008104",
-                "0.005496",
-                "0.009871",
-                "0.006008",
-                "0.007978",
-                "0.004733",
-            ],
-            "times": [
-                "0.099094",
-                "0.037129",
-                "0.036381",
-                "0.148896",
-                "0.008104",
-                "0.005496",
-                "0.009871",
-                "0.006008",
-                "0.007978",
-                "0.004733",
-            ],
+    if stats:
+        stats = {
+            "data": stats.get("data"),
+            "times": stats.get("times"),
             "unit": "s",
             "time_unit": "s",
-            "iqr": "0.030442",
+            "iqr": None,
             "iterations": 10,
-            "max": "0.148896",
-            "mean": "0.036369",
-            "median": "0.008988",
-            "min": "0.004733",
-            "q1": "0.006500",
-            "q3": "0.036942",
-            "stdev": "0.049194",
+            "max": None,
+            "mean": None,
+            "median": None,
+            "min": None,
+            "q1": None,
+            "q3": None,
+            "stdev": None,
             "z_score": None,
             "z_regression": False,
             "z_improvement": False,
-        },
+        }
+    elif error:
+        stats = {
+            "data": [],
+            "times": [],
+            "unit": None,
+            "time_unit": None,
+            "iqr": None,
+            "iterations": None,
+            "max": None,
+            "mean": None,
+            "median": None,
+            "min": None,
+            "q1": None,
+            "q3": None,
+            "stdev": None,
+            "z_score": None,
+            "z_regression": False,
+            "z_improvement": False,
+        }
+    else:
+        stats = {
+            "data": [
+                0.099094,
+                0.037129,
+                0.036381,
+                0.148896,
+                0.008104,
+                0.005496,
+                0.009871,
+                0.006008,
+                0.007978,
+                0.004733,
+            ],
+            "times": [
+                0.099094,
+                0.037129,
+                0.036381,
+                0.148896,
+                0.008104,
+                0.005496,
+                0.009871,
+                0.006008,
+                0.007978,
+                0.004733,
+            ],
+            "unit": "s",
+            "time_unit": "s",
+            "iqr": 0.030442,
+            "iterations": 10,
+            "max": 0.148896,
+            "mean": 0.036369,
+            "median": 0.008988,
+            "min": 0.004733,
+            "q1": 0.006500,
+            "q3": 0.036942,
+            "stdev": 0.049194,
+            "z_score": None,
+            "z_regression": False,
+            "z_improvement": False,
+        }
+    return {
+        "id": benchmark_result_id,
+        "run_id": run_id,
+        "batch_id": batch_id,
+        "timestamp": "2020-11-25T21:02:44Z",
+        "stats": stats,
+        "error": error,
+        "validation": validation,
+        "optional_benchmark_info": optional_benchmark_info,
+        "change_annotations": {},
         "tags": {
             "id": case_id,
             "compression": "snappy",
@@ -87,7 +135,7 @@ def _api_benchmark_entity(
         },
         "links": {
             "list": "http://localhost/api/benchmarks/",
-            "self": "http://localhost/api/benchmarks/%s/" % summary_id,
+            "self": "http://localhost/api/benchmarks/%s/" % benchmark_result_id,
             "context": "http://localhost/api/contexts/%s/" % context_id,
             "info": "http://localhost/api/info/%s/" % info_id,
             "run": "http://localhost/api/runs/%s/" % run_id,
@@ -102,15 +150,17 @@ def _api_commit_entity(commit_id, parent_id, links=True):
         "author_name": "Diana Clarke",
         "id": commit_id,
         "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
-        "repository": "https://github.com/apache/arrow",
+        "repository": "https://github.com/org/repo",
         "sha": "02addad336ba19a654f9c857ede546331be7b631",
-        "url": "https://github.com/apache/arrow/commit/02addad336ba19a654f9c857ede546331be7b631",
+        "url": "https://github.com/org/repo/commit/02addad336ba19a654f9c857ede546331be7b631",
         "parent_sha": "4beb514d071c9beec69b8917b5265e77ade22fb3",
         "timestamp": "2021-02-25T01:02:51",
         "links": {
             "list": "http://localhost/api/commits/",
             "self": "http://localhost/api/commits/%s/" % commit_id,
         },
+        "branch": "some_user_or_org:some_branch",
+        "fork_point_sha": "02addad336ba19a654f9c857ede546331be7b631",
     }
     if parent_id:
         result["links"]["parent"] = "http://localhost/api/commits/%s/" % parent_id
@@ -122,6 +172,7 @@ def _api_commit_entity(commit_id, parent_id, links=True):
 def _api_compare_entity(benchmark_ids, batch_ids, run_ids, batch, benchmark, tags):
     return {
         "baseline": "0.036 s",
+        "baseline_error": None,
         "baseline_id": benchmark_ids[0],
         "baseline_batch_id": batch_ids[0],
         "baseline_run_id": run_ids[0],
@@ -132,7 +183,7 @@ def _api_compare_entity(benchmark_ids, batch_ids, run_ids, batch, benchmark, tag
         "threshold": "5.000%",
         "regression": False,
         "improvement": False,
-        "threshold_z": "5.000",
+        "threshold_z": 5.0,
         "baseline_z_score": None,
         "contender_z_score": None,
         "baseline_z_regression": False,
@@ -140,6 +191,7 @@ def _api_compare_entity(benchmark_ids, batch_ids, run_ids, batch, benchmark, tag
         "contender_z_regression": False,
         "contender_z_improvement": False,
         "contender": "0.036 s",
+        "contender_error": None,
         "contender_id": benchmark_ids[1],
         "contender_batch_id": batch_ids[1],
         "contender_run_id": run_ids[1],
@@ -161,6 +213,7 @@ def _api_compare_list(
     return [
         {
             "baseline": "0.036 s",
+            "baseline_error": None,
             "baseline_id": baseline_ids[0],
             "baseline_batch_id": batch_ids[0],
             "baseline_run_id": run_ids[0],
@@ -171,7 +224,7 @@ def _api_compare_list(
             "threshold": "5.000%",
             "regression": False,
             "improvement": False,
-            "threshold_z": "5.000",
+            "threshold_z": 5.0,
             "baseline_z_score": None,
             "contender_z_score": None,
             "baseline_z_regression": False,
@@ -179,6 +232,7 @@ def _api_compare_list(
             "contender_z_regression": False,
             "contender_z_improvement": False,
             "contender": "0.036 s",
+            "contender_error": None,
             "contender_id": contender_ids[0],
             "contender_batch_id": batch_ids[1],
             "contender_run_id": run_ids[1],
@@ -188,6 +242,7 @@ def _api_compare_list(
         },
         {
             "baseline": "0.036 s",
+            "baseline_error": None,
             "baseline_id": baseline_ids[1],
             "baseline_batch_id": batch_ids[0],
             "baseline_run_id": run_ids[0],
@@ -198,7 +253,7 @@ def _api_compare_list(
             "threshold": "5.000%",
             "regression": False,
             "improvement": False,
-            "threshold_z": "5.000",
+            "threshold_z": 5.0,
             "baseline_z_score": None,
             "contender_z_score": None,
             "baseline_z_regression": False,
@@ -206,6 +261,7 @@ def _api_compare_list(
             "contender_z_regression": False,
             "contender_z_improvement": False,
             "contender": "0.036 s",
+            "contender_error": None,
             "contender_id": contender_ids[1],
             "contender_batch_id": batch_ids[1],
             "contender_run_id": run_ids[1],
@@ -216,7 +272,7 @@ def _api_compare_list(
     ]
 
 
-def _api_compare_summary(
+def _api_compare_benchmark_result(
     baseline_commit_id,
     contender_commit_id,
     baseline_id,
@@ -235,10 +291,12 @@ def _api_compare_summary(
                 "id": baseline_commit_id,
                 "message": "ARROW-11767: [C++] Scalar::Hash may segfault",
                 "parent_sha": "6d703c4c7b15be630af48d5e9ef61628751674b2",
-                "repository": "https://github.com/apache/arrow",
+                "repository": "https://github.com/org/repo",
                 "sha": "4beb514d071c9beec69b8917b5265e77ade22fb3",
                 "timestamp": "2021-02-24T22:12:11",
-                "url": "https://github.com/apache/arrow/commit/4beb514d071c9beec69b8917b5265e77ade22fb3",
+                "url": "https://github.com/org/repo/commit/4beb514d071c9beec69b8917b5265e77ade22fb3",
+                "branch": "some_user_or_org:some_branch",
+                "fork_point_sha": "4beb514d071c9beec69b8917b5265e77ade22fb3",
             },
             "contender": {
                 "author_avatar": "https://avatars.githubusercontent.com/u/878798?v=4",
@@ -247,10 +305,12 @@ def _api_compare_summary(
                 "id": contender_commit_id,
                 "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
                 "parent_sha": "4beb514d071c9beec69b8917b5265e77ade22fb3",
-                "repository": "https://github.com/apache/arrow",
+                "repository": "https://github.com/org/repo",
                 "sha": "02addad336ba19a654f9c857ede546331be7b631",
                 "timestamp": "2021-02-25T01:02:51",
-                "url": "https://github.com/apache/arrow/commit/02addad336ba19a654f9c857ede546331be7b631",
+                "url": "https://github.com/org/repo/commit/02addad336ba19a654f9c857ede546331be7b631",
+                "branch": "some_user_or_org:some_branch",
+                "fork_point_sha": "02addad336ba19a654f9c857ede546331be7b631",
             },
         },
         "links": {
@@ -259,7 +319,7 @@ def _api_compare_summary(
         "runs": [
             {
                 "baseline": {
-                    "machine_name": "diana",
+                    "hardware_name": "diana",
                     "run": f"http://localhost/api/runs/{baseline_id}/",
                     "run_id": baseline_id,
                     "run_name": baseline_name,
@@ -267,7 +327,7 @@ def _api_compare_summary(
                 },
                 "compare": f"http://localhost/api/compare/runs/{baseline_id}...{contender_id}/",
                 "contender": {
-                    "machine_name": "diana",
+                    "hardware_name": "diana",
                     "run": f"http://localhost/api/runs/{contender_id}/",
                     "run_id": contender_id,
                     "run_name": contender_name,
@@ -298,12 +358,15 @@ def _api_history_entity(benchmark_id, case_id, context_id, run_name):
         "benchmark_id": benchmark_id,
         "case_id": case_id,
         "context_id": context_id,
-        "machine_hash": "diana-2-2-4-17179869184",
+        "hardware_hash": "diana-2-2-4-17179869184",
         "unit": "s",
-        "mean": "0.036369",
-        "distribution_mean": "0.036369",
-        "distribution_stdev": "0.000000",
-        "repository": "https://github.com/apache/arrow",
+        "data": BENCHMARK_ENTITY["stats"]["data"],
+        "times": BENCHMARK_ENTITY["stats"]["times"],
+        "mean": 0.036369,
+        "begins_distribution_change": False,
+        "distribution_mean": 0.036369,
+        "distribution_stdev": 0.000000,
+        "repository": "https://github.com/org/repo",
         "sha": "02addad336ba19a654f9c857ede546331be7b631",
         "timestamp": "2021-02-25T01:02:51",
         "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
@@ -328,30 +391,46 @@ def _api_info_entity(info_id, links=True):
     return result
 
 
-def _api_machine_entity(machine_id, machine_name, links=True):
-    result = {
-        "id": machine_id,
-        "architecture_name": "x86_64",
-        "cpu_l1d_cache_bytes": 32768,
-        "cpu_l1i_cache_bytes": 32768,
-        "cpu_l2_cache_bytes": 262144,
-        "cpu_l3_cache_bytes": 4194304,
-        "cpu_core_count": 2,
-        "cpu_frequency_max_hz": 3500000000,
-        "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
-        "cpu_thread_count": 4,
-        "kernel_name": "19.6.0",
-        "memory_bytes": 17179869184,
-        "name": machine_name,
-        "os_name": "macOS",
-        "os_version": "10.15.7",
-        "gpu_count": 2,
-        "gpu_product_names": ["Tesla T4", "GeForce GTX 1060 3GB"],
-        "links": {
-            "list": "http://localhost/api/machines/",
-            "self": "http://localhost/api/machines/%s/" % machine_id,
-        },
-    }
+def _api_hardware_entity(
+    hardware_id, hardware_name, hardware_type="machine", links=True
+):
+    if hardware_type == "machine":
+        result = {
+            "id": hardware_id,
+            "type": "machine",
+            "architecture_name": "x86_64",
+            "cpu_l1d_cache_bytes": 32768,
+            "cpu_l1i_cache_bytes": 32768,
+            "cpu_l2_cache_bytes": 262144,
+            "cpu_l3_cache_bytes": 4194304,
+            "cpu_core_count": 2,
+            "cpu_frequency_max_hz": 3500000000,
+            "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
+            "cpu_thread_count": 4,
+            "kernel_name": "19.6.0",
+            "memory_bytes": 17179869184,
+            "name": hardware_name,
+            "os_name": "macOS",
+            "os_version": "10.15.7",
+            "gpu_count": 2,
+            "gpu_product_names": ["Tesla T4", "GeForce GTX 1060 3GB"],
+            "links": {
+                "list": "http://localhost/api/hardware/",
+                "self": "http://localhost/api/hardware/%s/" % hardware_id,
+            },
+        }
+    else:
+        result = {
+            "id": hardware_id,
+            "type": "cluster",
+            "info": {"gpu": 1},
+            "optional_info": {"workers": 1},
+            "name": hardware_name,
+            "links": {
+                "list": "http://localhost/api/hardware/",
+                "self": "http://localhost/api/hardware/%s/" % hardware_id,
+            },
+        }
     if not links:
         result.pop("links", None)
     return result
@@ -360,25 +439,40 @@ def _api_machine_entity(machine_id, machine_name, links=True):
 def _api_run_entity(
     run_id,
     run_name,
+    run_reason,
     commit_id,
     parent_id,
-    machine_id,
-    machine_name,
+    hardware_id,
+    hardware_name,
+    hardware_type,
     now,
     baseline_id,
     include_baseline=True,
+    has_errors=False,
+    finished_timestamp=None,
+    info=None,
+    error_info=None,
+    error_type=None,
 ):
     result = {
         "id": run_id,
         "name": run_name,
+        "reason": run_reason,
         "timestamp": now,
+        "finished_timestamp": finished_timestamp,
+        "info": info,
+        "error_info": error_info,
+        "error_type": error_type,
         "commit": _api_commit_entity(commit_id, parent_id, links=False),
-        "machine": _api_machine_entity(machine_id, machine_name, links=False),
+        "hardware": _api_hardware_entity(
+            hardware_id, hardware_name, hardware_type, links=False
+        ),
+        "has_errors": has_errors,
         "links": {
             "list": "http://localhost/api/runs/",
             "self": "http://localhost/api/runs/%s/" % run_id,
             "commit": "http://localhost/api/commits/%s/" % commit_id,
-            "machine": "http://localhost/api/machines/%s/" % machine_id,
+            "hardware": "http://localhost/api/hardware/%s/" % hardware_id,
         },
     }
     baseline_url = None
@@ -446,7 +540,7 @@ COMPARE_LIST = _api_compare_list(
         },
     ],
 )
-COMPARE_SUMMARY = _api_compare_summary(
+COMPARE_BENCHMARK_RESULT = _api_compare_benchmark_result(
     "some-baseline-commit-id",
     "some-contender-commit-id",
     "some-baseline-run-id",
@@ -464,14 +558,16 @@ HISTORY_ENTITY = _api_history_entity(
     "some run name",
 )
 INFO_ENTITY = _api_info_entity("some-info-uuid-1")
-MACHINE_ENTITY = _api_machine_entity("some-machine-uuid-1", "some-machine-name")
+HARDWARE_ENTITY = _api_hardware_entity("some-machine-uuid-1", "some-machine-name")
 RUN_ENTITY = _api_run_entity(
     "some-run-uuid-1",
     "some run name",
+    "some run reason",
     "some-commit-uuid-1",
     "some-parent-commit-uuid-1",
     "some-machine-uuid-1",
     "some-machine-name",
+    "machine",
     "2021-02-04T17:22:05.225583",
     "some-run-uuid-0",
 )
@@ -479,10 +575,12 @@ RUN_LIST = [
     _api_run_entity(
         "some-run-uuid-1",
         "some run name",
+        "some run reason",
         "some-commit-uuid-1",
         "some-parent-commit-uuid-1",
         "some-machine-uuid-1",
         "some-machine-name",
+        "machine",
         "2021-02-04T17:22:05.225583",
         None,
         include_baseline=False,
@@ -522,7 +620,7 @@ API_INDEX = {
         "login": "http://localhost/api/login/",
         "logout": "http://localhost/api/logout/",
         "info": "http://localhost/api/info/",
-        "machines": "http://localhost/api/machines/",
+        "hardware": "http://localhost/api/hardware/",
         "register": "http://localhost/api/register/",
         "runs": "http://localhost/api/runs/",
         "ping": "http://localhost/api/ping/",
