@@ -5,9 +5,13 @@ from ..api import rule
 from ..api._docs import spec
 from ..api._endpoint import ApiEndpoint, maybe_login_required
 from ..entities._entity import NotFound
+from ..entities.benchmark_result import (
+    BenchmarkFacadeSchema,
+    BenchmarkResult,
+    BenchmarkResultSerializer,
+)
 from ..entities.case import Case
-from ..entities.distribution import set_z_scores
-from ..entities.summary import BenchmarkFacadeSchema, Summary, SummarySerializer
+from ..entities.history import set_z_scores
 
 
 class BenchmarkValidationMixin:
@@ -16,14 +20,15 @@ class BenchmarkValidationMixin:
 
 
 class BenchmarkEntityAPI(ApiEndpoint, BenchmarkValidationMixin):
-    serializer = SummarySerializer()
+    serializer = BenchmarkResultSerializer()
+    schema = BenchmarkFacadeSchema()
 
     def _get(self, benchmark_id):
         try:
-            summary = Summary.one(id=benchmark_id)
+            benchmark_result = BenchmarkResult.one(id=benchmark_id)
         except NotFound:
             self.abort_404_not_found()
-        return summary
+        return benchmark_result
 
     @maybe_login_required
     def get(self, benchmark_id):
@@ -42,9 +47,36 @@ class BenchmarkEntityAPI(ApiEndpoint, BenchmarkValidationMixin):
         tags:
           - Benchmarks
         """
-        summary = self._get(benchmark_id)
-        set_z_scores([summary])
-        return self.serializer.one.dump(summary)
+        benchmark_result = self._get(benchmark_id)
+        set_z_scores([benchmark_result])
+        return self.serializer.one.dump(benchmark_result)
+
+    @flask_login.login_required
+    def put(self, benchmark_id):
+        """
+        ---
+        description: Edit a benchmark.
+        responses:
+            "200": "BenchmarkEntity"
+            "401": "401"
+            "404": "404"
+        parameters:
+          - name: benchmark_id
+            in: path
+            schema:
+                type: string
+        requestBody:
+            content:
+                application/json:
+                    schema: BenchmarkUpdate
+        tags:
+          - Benchmarks
+        """
+        benchmark_result = self._get(benchmark_id)
+        data = self.validate_benchmark(self.schema.update)
+        benchmark_result.update(data)
+        set_z_scores([benchmark_result])
+        return self.serializer.one.dump(benchmark_result)
 
     @flask_login.login_required
     def delete(self, benchmark_id):
@@ -63,13 +95,13 @@ class BenchmarkEntityAPI(ApiEndpoint, BenchmarkValidationMixin):
         tags:
           - Benchmarks
         """
-        summary = self._get(benchmark_id)
-        summary.delete()
+        benchmark_result = self._get(benchmark_id)
+        benchmark_result.delete()
         return self.response_204_no_content()
 
 
 class BenchmarkListAPI(ApiEndpoint, BenchmarkValidationMixin):
-    serializer = SummarySerializer()
+    serializer = BenchmarkResultSerializer()
     schema = BenchmarkFacadeSchema()
 
     @maybe_login_required
@@ -96,37 +128,49 @@ class BenchmarkListAPI(ApiEndpoint, BenchmarkValidationMixin):
         tags:
           - Benchmarks
         """
-        name = f.request.args.get("name")
-        batch_id = f.request.args.get("batch_id")
-        run_id = f.request.args.get("run_id")
-        if name:
-            summaries = Summary.search(
-                filters=[Case.name == name],
+        if name_arg := f.request.args.get("name"):
+            benchmark_results = BenchmarkResult.search(
+                filters=[Case.name == name_arg],
                 joins=[Case],
             )
-            # TODO: cannot currently compute z_score on an arbitrary
-            # list of summaries - assumes same machine/sha/repository.
-            for summary in summaries:
-                summary.z_score = 0
-        elif batch_id:
-            summaries = Summary.all(batch_id=batch_id)
-            set_z_scores(summaries)
-        elif run_id:
-            summaries = Summary.all(run_id=run_id)
-            set_z_scores(summaries)
+            # Since there's no limit on the number of BenchmarkResults, we could take
+            # forever calculating z-scores with no caching advantage. So don't do that.
+            for benchmark_result in benchmark_results:
+                benchmark_result.z_score = None
+        elif batch_id_arg := f.request.args.get("batch_id"):
+            batch_ids = batch_id_arg.split(",")
+            benchmark_results = BenchmarkResult.search(
+                filters=[BenchmarkResult.batch_id.in_(batch_ids)]
+            )
+            set_z_scores(benchmark_results)
+        elif run_id_arg := f.request.args.get("run_id"):
+            run_ids = run_id_arg.split(",")
+            benchmark_results = BenchmarkResult.search(
+                filters=[BenchmarkResult.run_id.in_(run_ids)]
+            )
+            set_z_scores(benchmark_results)
         else:
-            summaries = Summary.all(order_by=Summary.timestamp.desc(), limit=500)
-            # TODO: cannot currently compute z_score on an arbitrary
-            # list of summaries - assumes same machine/sha/repository.
-            for summary in summaries:
-                summary.z_score = 0
-        return self.serializer.many.dump(summaries)
+            benchmark_results = BenchmarkResult.all(
+                order_by=BenchmarkResult.timestamp.desc(), limit=500
+            )
+            # Setting z-scores takes too long for this one too.
+            for benchmark_result in benchmark_results:
+                benchmark_result.z_score = None
+
+        return self.serializer.many.dump(benchmark_results)
 
     @flask_login.login_required
     def post(self):
         """
         ---
-        description: Create a benchmark.
+        description:
+            Submit a BenchmarkResult within a specific Run.
+
+            If the Run (as defined by its Run ID) is not known yet in the
+            database it gets implicitly created, using details provided in this
+            request. If the Run ID matches an existing run, then the rest of
+            the fields describing the Run (such as name, hardware info, ...}
+            are silently ignored.
         responses:
             "201": "BenchmarkCreated"
             "400": "400"
@@ -139,9 +183,9 @@ class BenchmarkListAPI(ApiEndpoint, BenchmarkValidationMixin):
           - Benchmarks
         """
         data = self.validate_benchmark(self.schema.create)
-        summary = Summary.create(data)
-        set_z_scores([summary])
-        return self.response_201_created(self.serializer.one.dump(summary))
+        benchmark_result = BenchmarkResult.create(data)
+        set_z_scores([benchmark_result])
+        return self.response_201_created(self.serializer.one.dump(benchmark_result))
 
 
 benchmark_entity_view = BenchmarkEntityAPI.as_view("benchmark")
@@ -155,6 +199,7 @@ rule(
 rule(
     "/benchmarks/<benchmark_id>/",
     view_func=benchmark_entity_view,
-    methods=["GET", "DELETE"],
+    methods=["GET", "DELETE", "PUT"],
 )
 spec.components.schema("BenchmarkCreate", schema=BenchmarkFacadeSchema.create)
+spec.components.schema("BenchmarkUpdate", schema=BenchmarkFacadeSchema.update)
