@@ -10,6 +10,7 @@ def augment(benchmark, contexts=None):
     set_display_batch(benchmark)
     set_display_mean(benchmark)
     set_display_language(benchmark, contexts)
+    set_display_error(benchmark)
     tags = benchmark["tags"]
     if "dataset" in tags:
         tags["dataset"] = dataset_name(tags["dataset"])
@@ -19,8 +20,16 @@ def dataset_name(name):
     return name.replace("_", " ")
 
 
-def display_time(t):
-    return t.split(".")[0].replace("T", "  ").rsplit(":", 1)[0] if t else ""
+def display_time(t: str):
+    """
+    Expect `t` to be an ISO 8601 compliant string
+    - that encodes the UTC timezone with a Z suffix
+    - that does not contain fractions of seconds
+
+    Input example:  "2023-01-31Z05:36:45Z"
+    Output example: "2023-01-31 05:36:45 UTC"
+    """
+    return t.replace("T", " ").replace("Z", " UTC")
 
 
 def set_display_language(benchmark, contexts):
@@ -36,12 +45,20 @@ def set_display_time(benchmark):
 
 
 def set_display_mean(benchmark):
+    if not benchmark["stats"]["mean"]:
+        return ""
+
     unit = benchmark["stats"]["unit"]
     mean = float(benchmark["stats"]["mean"])
     fmt = formatter_for_unit(unit)
     benchmark["display_mean"] = fmt(mean, unit)
 
 
+def set_display_error(benchmark):
+    if not benchmark["error"]:
+        benchmark["error"] = ""
+
+
 def display_message(message):
     # truncate git shas in commit message
     for m in re.findall(r"\b[0-9a-f]{40}\b", message):
