@@ -1,5 +1,8 @@
+import logging
 import os
+from typing import Optional
 
+import flask as f
 import flask_login
 import flask_wtf
 import wtforms as w
@@ -10,6 +13,8 @@ from ..app._endpoint import AppEndpoint
 from ..config import Config
 from ..entities.user import User
 
+log = logging.getLogger(__name__)
+
 
 class Logout(AppEndpoint):
     def get(self):
@@ -27,14 +32,35 @@ class LoginForm(flask_wtf.FlaskForm):
 class Login(AppEndpoint):
     form = LoginForm
 
-    def page(self, form):
-        sso = os.environ.get("GOOGLE_CLIENT_ID", None) is not None
+    def page(self, form, target_url_after_login: Optional[str] = None):
+        """
+        `target_url_after_login` is meant to carry an absolute or relative URL,
+        the target to redirect the user to after login was successful.
+        """
+
+        show_sso_button = False
+
+        if (
+            Config.OIDC_CLIENT_ID
+            and Config.OIDC_CLIENT_SECRET
+            and Config.OIDC_ISSUER_URL
+        ):
+            show_sso_button = True
+
+        # Legacy method for determining whether or not to show the SSO
+        # link/button: remove when GOOGLE_CLIENT_ID gets phased out.
+        if os.environ.get("GOOGLE_CLIENT_ID") is not None:
+            show_sso_button = True
+
         return self.render_template(
             "login.html",
             application=Config.APPLICATION_NAME,
             title="Sign In",
             form=form,
-            sso=sso,
+            sso=show_sso_button,
+            # If `target_url_after_login` is Falsy (e.g. emtpy string) then
+            # expect template to not add a query parameter to the login link.
+            target_url_after_login=target_url_after_login,
         )
 
     def data(self, form):
@@ -45,11 +71,25 @@ class Login(AppEndpoint):
         }
 
     def get(self):
+        # Read query parameter `target`. Assume that the value is the URL that
+        # the user actually wanted to visit before they were redirected to the
+        # login page. `f.request.args` holds parsed (i.e. URL-decoded) URL
+        # query parameters.
+        user_came_from_url = ""
+        if "target" in f.request.args:
+            user_came_from_url = f.request.args.get("target")
+            log.debug("render login page. target param: %s", user_came_from_url)
+
         if flask_login.current_user.is_authenticated:
+            # Redirect to target if set? Might create infinite redirect loop.
             return self.redirect("app.index")
-        return self.page(self.form())
+
+        return self.page(self.form(), target_url_after_login=user_came_from_url)
 
     def post(self):
+        """
+        Note: redirect-to-target-after-login not yet implemented
+        """
         if flask_login.current_user.is_authenticated:
             return self.redirect("app.index")
 
@@ -59,7 +99,11 @@ class Login(AppEndpoint):
             if response.status_code == 204:
                 # TODO: remove this last query from frontend
                 user = User.first(email=form.email.data)
+                # NOTE(JP): this is the second time that we call
+                # `flask_login.login_user` while the actual user agent waits
+                # for an HTTP response.
                 flask_login.login_user(user, remember=form.remember_me.data)
+
                 return self.redirect("app.index")
             else:
                 self.flash("Invalid email or password.", "danger")
