@@ -1,32 +1,35 @@
+import flask as f
+
 from .. import __version__
 from ..app import rule
-from ..app._endpoint import AppEndpoint
+from ..app._endpoint import AppEndpoint, authorize_or_terminate
 from ..app.benchmarks import RunMixin
+from ..buildinfo import BUILD_INFO
 from ..config import Config
 
+# Default to importlib_metadata version string.
+VERSION_STRING_FOOTER = __version__
+
+
+# Enrich with short commit hash, if available.
+# Also see https://github.com/conbench/conbench/issues/461
+if BUILD_INFO is not None:
+    VERSION_STRING_FOOTER = f"{__version__}-{BUILD_INFO.commit[:9]}"
+
 
 class Index(AppEndpoint, RunMixin):
     def page(self, runs):
-        reasons = {r["display_name"] for r in runs if r["display_name"]}
-        commits = {r["commit"]["url"] for r in runs if r["commit"]["url"]}
-        authors = {
-            r["commit"]["author_name"] for r in runs if r["commit"]["author_name"]
-        }
         return self.render_template(
             "index.html",
             application=Config.APPLICATION_NAME,
             title="Home",
-            version=__version__,
+            version_string_footer=VERSION_STRING_FOOTER,
             runs=runs,
-            has_reasons=len(reasons) > 0,
-            has_authors=len(authors) > 0,
-            has_commits=len(commits) > 0,
+            search_value=f.request.args.get("search"),
         )
 
+    @authorize_or_terminate
     def get(self):
-        if self.public_data_off():
-            return self.redirect("app.login")
-
         runs = self.get_display_runs()
         return self.page(runs)
 
