@@ -1,7 +1,7 @@
 from ...api._examples import (
+    _api_compare_benchmark_result,
     _api_compare_entity,
     _api_compare_list,
-    _api_compare_summary,
 )
 from ...api.compare import _get_pairs
 from ...tests.api import _asserts, _fixtures
@@ -15,14 +15,15 @@ class FakeEntity:
         self.id = _id
 
 
-def _fake_compare_entity(summary_id, case_id, context_id):
+def _fake_compare_entity(benchmark_result_id, case_id, context_id, error=None):
     return {
-        "id": summary_id,
+        "id": benchmark_result_id,
         "batch_id": "some_batch_id",
         "run_id": "some_run_id",
         "case_id": case_id,
         "context_id": context_id,
         "value": "some_value",
+        "error": error,
         "unit": "some_unit",
         "benchmark": "some_benchmark",
         "batch": "some_batch",
@@ -176,24 +177,48 @@ class TestCompareBenchmarksGet(_asserts.GetEnforcer):
 
     def _create(self, name=None, verbose=False):
         # create a distribution history & a regression
-        _fixtures.summary(
+        _fixtures.benchmark_result(
             name=name,
             results=_fixtures.RESULTS_UP[0],
             sha=_fixtures.GRANDPARENT,
         )
-        summary_1 = _fixtures.summary(
+        benchmark_result_1 = _fixtures.benchmark_result(
             name=name,
             results=_fixtures.RESULTS_UP[1],
             sha=_fixtures.PARENT,
         )
-        summary_2 = _fixtures.summary(
+        benchmark_result_2 = _fixtures.benchmark_result(
             name=name,
             results=_fixtures.RESULTS_UP[2],
         )
 
-        entity = FakeEntity(f"{summary_1.id}...{summary_2.id}")
+        entity = FakeEntity(f"{benchmark_result_1.id}...{benchmark_result_2.id}")
         if verbose:
-            return [summary_1, summary_2], entity
+            return [benchmark_result_1, benchmark_result_2], entity
+        return entity
+
+    def _create_with_error(self, name=None, baseline_error=None, verbose=False):
+        # create a distribution history & a regression
+        _fixtures.benchmark_result(
+            name=name,
+            results=_fixtures.RESULTS_UP[0],
+            sha=_fixtures.GRANDPARENT,
+        )
+        benchmark_result_1 = _fixtures.benchmark_result(
+            name=name,
+            results=None,
+            sha=_fixtures.PARENT,
+            error=baseline_error,
+            empty_results=True,
+        )
+        benchmark_result_2 = _fixtures.benchmark_result(
+            name=name,
+            results=_fixtures.RESULTS_UP[2],
+        )
+
+        entity = FakeEntity(f"{benchmark_result_1.id}...{benchmark_result_2.id}")
+        if verbose:
+            return [benchmark_result_1, benchmark_result_2], entity
         return entity
 
     def test_compare(self, client):
@@ -227,12 +252,54 @@ class TestCompareBenchmarksGet(_asserts.GetEnforcer):
                 "change": "-566.667%",
                 "regression": True,
                 "baseline_z_score": None,
-                "contender_z_score": "-{:.3f}".format(_fixtures.Z_SCORE_UP),
+                "contender_z_score": -_fixtures.Z_SCORE_UP_COMPUTED_VIA_POSTGRES,
                 "contender_z_regression": True,
             }
         )
         self.assert_200_ok(response, expected)
 
+    def test_compare_with_error(self, client):
+        self.authenticate(client)
+        name = _uuid()
+        error = {"stack trace": "stack trace"}
+        new_entities, compare = self._create_with_error(
+            name, baseline_error=error, verbose=True
+        )
+        response = client.get(f"/api/compare/benchmarks/{compare.id}/")
+
+        benchmark_ids = [e.id for e in new_entities]
+        batch_ids = [e.batch_id for e in new_entities]
+        run_ids = [e.run_id for e in new_entities]
+        expected = _api_compare_entity(
+            benchmark_ids,
+            batch_ids,
+            run_ids,
+            name,
+            CASE,
+            tags={
+                "dataset": "nyctaxi_sample",
+                "cpu_count": 2,
+                "file_type": "parquet",
+                "input_type": "arrow",
+                "compression": "snappy",
+                "name": name,
+            },
+        )
+        expected.update(
+            {
+                "baseline": None,
+                "baseline_error": error,
+                "contender": "20.000 s",
+                "change": "0.000%",
+                "regression": False,
+                "baseline_z_score": None,
+                "contender_z_score": None,
+                "contender_z_regression": False,
+            }
+        )
+
+        self.assert_200_ok(response, expected)
+
     def test_compare_unknown_compare_ids(self, client):
         self.authenticate(client)
         response = client.get("/api/compare/benchmarks/foo...bar/")
@@ -245,19 +312,19 @@ class TestCompareBatchesGet(_asserts.GetEnforcer):
 
     def _create(self, verbose=False, run_id=None, batch_id=None):
         batch_id = batch_id if batch_id is not None else _uuid()
-        summary_1 = _fixtures.summary(
+        benchmark_result_1 = _fixtures.benchmark_result(
             name="read",
             run_id=run_id,
             batch_id=batch_id,
         )
-        summary_2 = _fixtures.summary(
+        benchmark_result_2 = _fixtures.benchmark_result(
             name="write",
             run_id=run_id,
             batch_id=batch_id,
         )
         entity = FakeEntity(f"{batch_id}...{batch_id}")
         if verbose:
-            return [summary_1, summary_2], entity
+            return [benchmark_result_1, benchmark_result_2], entity
         return entity
 
     def test_compare(self, client):
@@ -302,7 +369,8 @@ class TestCompareBatchesGet(_asserts.GetEnforcer):
                 },
             ],
         )
-        self.assert_200_ok(response, expected)
+        self.assert_200_ok(response, None, contains=expected[0])
+        self.assert_200_ok(response, None, contains=expected[1])
 
     def test_compare_unknown_compare_ids(self, client):
         self.authenticate(client)
@@ -316,19 +384,41 @@ class TestCompareRunsGet(_asserts.GetEnforcer):
 
     def _create(self, verbose=False, run_id=None, batch_id=None):
         run_id = run_id if run_id is not None else _uuid()
-        summary_1 = _fixtures.summary(
+        benchmark_result_1 = _fixtures.benchmark_result(
             name="read",
             run_id=run_id,
             batch_id=batch_id,
         )
-        summary_2 = _fixtures.summary(
+        benchmark_result_2 = _fixtures.benchmark_result(
             name="write",
             run_id=run_id,
             batch_id=batch_id,
         )
         entity = FakeEntity(f"{run_id}...{run_id}")
         if verbose:
-            return [summary_1, summary_2], entity
+            return [benchmark_result_1, benchmark_result_2], entity
+        return entity
+
+    def _create_with_error(
+        self, verbose=False, run_id=None, batch_id=None, baseline_error=None
+    ):
+        run_id = run_id if run_id is not None else _uuid()
+        benchmark_result_1 = _fixtures.benchmark_result(
+            name="read",
+            run_id=run_id,
+            batch_id=batch_id,
+        )
+        benchmark_result_2 = _fixtures.benchmark_result(
+            name="write",
+            run_id=run_id,
+            batch_id=batch_id,
+            results=None,
+            error=baseline_error,
+            empty_results=True,
+        )
+        entity = FakeEntity(f"{run_id}...{run_id}")
+        if verbose:
+            return [benchmark_result_1, benchmark_result_2], entity
         return entity
 
     def test_compare(self, client):
@@ -373,7 +463,69 @@ class TestCompareRunsGet(_asserts.GetEnforcer):
                 },
             ],
         )
-        self.assert_200_ok(response, expected)
+        self.assert_200_ok(response, None, contains=expected[0])
+        self.assert_200_ok(response, None, contains=expected[1])
+
+    def test_compare_with_error(self, client):
+        self.authenticate(client)
+        run_id, batch_id = _uuid(), _uuid()
+        error = {"stack trace": "stack trace"}
+        new_entities, compare = self._create_with_error(
+            verbose=True,
+            run_id=run_id,
+            batch_id=batch_id,
+            baseline_error=error,
+        )
+        new_ids = [e.id for e in new_entities]
+        response = client.get(f"/api/compare/runs/{compare.id}/")
+
+        # cheating by comparing run to same run
+        run_ids = [run_id, run_id]
+        batch_ids = [batch_id, batch_id]
+        batches = ["read", "write"]
+        benchmarks = [CASE, CASE]
+        expected = _api_compare_list(
+            new_ids,
+            new_ids,
+            batch_ids,
+            run_ids,
+            batches,
+            benchmarks,
+            tags=[
+                {
+                    "dataset": "nyctaxi_sample",
+                    "cpu_count": 2,
+                    "file_type": "parquet",
+                    "input_type": "arrow",
+                    "compression": "snappy",
+                    "name": "read",
+                },
+                {
+                    "dataset": "nyctaxi_sample",
+                    "cpu_count": 2,
+                    "file_type": "parquet",
+                    "input_type": "arrow",
+                    "compression": "snappy",
+                    "name": "write",
+                },
+            ],
+        )
+        expected[1].update(
+            {
+                "baseline": None,
+                "baseline_error": error,
+                "contender": None,
+                "contender_error": error,
+                "change": "0.000%",
+                "regression": False,
+                "baseline_z_score": None,
+                "contender_z_score": None,
+                "contender_z_regression": False,
+                "unit": "unknown",
+            }
+        )
+        self.assert_200_ok(response, None, contains=expected[0])
+        self.assert_200_ok(response, None, contains=expected[1])
 
     def test_compare_unknown_compare_ids(self, client):
         self.authenticate(client)
@@ -387,11 +539,11 @@ class TestCompareCommitsGet(_asserts.GetEnforcer):
 
     def _create(self, verbose=False):
         name = _uuid()
-        contender = _fixtures.summary(
+        contender = _fixtures.benchmark_result(
             name=name,
             sha=_fixtures.CHILD,
         )
-        baseline = _fixtures.summary(
+        baseline = _fixtures.benchmark_result(
             name=name,
             sha=_fixtures.PARENT,
         )
@@ -407,7 +559,7 @@ class TestCompareCommitsGet(_asserts.GetEnforcer):
         self.authenticate(client)
         [baseline, contender], compare = self._create(verbose=True)
         response = client.get(f"/api/compare/commits/{compare.id}/")
-        expected = _api_compare_summary(
+        expected = _api_compare_benchmark_result(
             baseline.commit.id,
             contender.commit.id,
             baseline.id,
