@@ -9,7 +9,7 @@ HISTORY = [
         "context_id": "a348db873c3641a9a13b57e934984525",
         "distribution_mean": "392130886.117931",
         "distribution_stdev": "0.000000",
-        "machine_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
+        "hardware_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
         "mean": "392130886.117931",
         "message": "ARROW-13429: [C++][Gandiva] Fix Gandiva codegen for if-else expression with binary type",
         "repository": "https://github.com/apache/arrow",
@@ -24,7 +24,7 @@ HISTORY = [
         "context_id": "a348db873c3641a9a13b57e934984525",
         "distribution_mean": "388236410.822258",
         "distribution_stdev": "5507619.781468",
-        "machine_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
+        "hardware_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
         "mean": "384341935.526585",
         "message": "ARROW-12388: [C++][Gandiva] Implement cast numbers from varbinary functions in gandiva",
         "repository": "https://github.com/apache/arrow",
@@ -39,7 +39,7 @@ HISTORY = [
         "context_id": "a348db873c3641a9a13b57e934984525",
         "distribution_mean": "386395506.239738",
         "distribution_stdev": "5033262.051040",
-        "machine_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
+        "hardware_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
         "mean": "382713697.074697",
         "message": "ARROW-12479: [C++][Gandiva] Implement castBigInt, castInt, castIntervalDay and castIntervalYear extra functions",
         "repository": "https://github.com/apache/arrow",
@@ -54,7 +54,7 @@ HISTORY = [
         "context_id": "a348db873c3641a9a13b57e934984525",
         "distribution_mean": "387124231.233692",
         "distribution_stdev": "4360425.634830",
-        "machine_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
+        "hardware_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
         "mean": "389310406.215554",
         "message": "ARROW-12410: [C++][Gandiva] Implement regexp_replace function on Gandiva",
         "repository": "https://github.com/apache/arrow",
@@ -69,7 +69,7 @@ HISTORY = [
         "context_id": "a348db873c3641a9a13b57e934984525",
         "distribution_mean": "387968509.336751",
         "distribution_stdev": "4221849.282505",
-        "machine_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
+        "hardware_hash": "ursa-thinkcentre-m75q-6-6-16106127360",
         "mean": "391345621.748988",
         "message": "ARROW-12866: [C++][Gandiva] Implement STRPOS function on Gandiva",
         "repository": "https://github.com/apache/arrow",
@@ -81,11 +81,11 @@ HISTORY = [
 ]
 
 DATES = [
-    datetime.datetime(2021, 8, 4, 10, 26, 7),
-    datetime.datetime(2021, 8, 4, 10, 28, 54),
-    datetime.datetime(2021, 8, 4, 10, 30, 10),
-    datetime.datetime(2021, 8, 4, 10, 31, 35),
-    datetime.datetime(2021, 8, 4, 10, 36, 39),
+    datetime.datetime(2021, 8, 4, 10, 26, 7, tzinfo=datetime.timezone.utc),
+    datetime.datetime(2021, 8, 4, 10, 28, 54, tzinfo=datetime.timezone.utc),
+    datetime.datetime(2021, 8, 4, 10, 30, 10, tzinfo=datetime.timezone.utc),
+    datetime.datetime(2021, 8, 4, 10, 31, 35, tzinfo=datetime.timezone.utc),
+    datetime.datetime(2021, 8, 4, 10, 36, 39, tzinfo=datetime.timezone.utc),
 ]
 COMMITS = [
     "ARROW-13429: [C++][Gandiva] Fix Gandiva codegen for if-else expression with binary type",
@@ -177,56 +177,56 @@ def test__source():
     source = _source(HISTORY, "B/s")
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS
-    assert source.data["means"] == MEANS
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_formatted():
     source = _source(HISTORY, "B/s", formatted=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_FORMATTED
-    assert source.data["means"] == MEANS
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_formatted_items_per_second():
     source = _source(HISTORY, "i/s", formatted=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_FORMATTED_ITEMS
-    assert source.data["means"] == MEANS_ITEMS
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS_ITEMS
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_alert_min():
     source = _source(HISTORY, "B/s", alert_min=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_MIN
-    assert source.data["means"] == MEANS_MIN
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS_MIN
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_alert_min_formatted():
     source = _source(HISTORY, "B/s", alert_min=True, formatted=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_MIN_FORMATTED
-    assert source.data["means"] == MEANS_MIN
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS_MIN
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_alert_max():
     source = _source(HISTORY, "B/s", alert_max=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_MAX
-    assert source.data["means"] == MEANS_MAX
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS_MAX
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_source_alert_max_formatted():
     source = _source(HISTORY, "B/s", alert_max=True, formatted=True)
     assert source.data["x"] == DATES
     assert source.data["y"] == POINTS_MAX_FORMATTED
-    assert source.data["means"] == MEANS_MAX
-    assert source.data["commits"] == COMMITS
+    assert source.data["values_with_unit"] == MEANS_MAX
+    assert source.data["commit_messages"] == COMMITS
 
 
 def test_should_format():
