@@ -8,6 +8,7 @@ from ...util import register_benchmarks
 
 __version__ = importlib_metadata.version("conbench")
 
+pytestmark = pytest.mark.filterwarnings("ignore::conbench.machine_info.GitParseWarning")
 
 CONBENCH = """
 Usage: conbench [OPTIONS] COMMAND [ARGS]...
@@ -18,14 +19,16 @@ Options:
   --help  Show this message and exit.
 
 Commands:
-  addition            Run addition benchmark.
-  external            Run external benchmark.
-  external-r          Run external-r benchmark.
-  external-r-options  Run external-r-options benchmark.
-  list                List of benchmarks (for orchestration).
-  matrix              Run matrix benchmark(s).
-  matrix-types        Run matrix-types benchmark(s).
-  version             Display Conbench version.
+  addition               Run addition benchmark.
+  division-with-failure  Run division-with-failure benchmark.
+  external               Run external benchmark.
+  external-r             Run external-r benchmark.
+  external-r-options     Run external-r-options benchmark.
+  list                   List of benchmarks (for orchestration).
+  matrix                 Run matrix benchmark(s).
+  matrix-types           Run matrix-types benchmark(s).
+  product                Run product benchmark.
+  version                Display Conbench version.
 """
 
 CONBENCH_LIST = """
@@ -33,6 +36,9 @@ CONBENCH_LIST = """
   {
     "command": "addition --iterations=2"
   },
+  {
+    "command": "division-with-failure --iterations=2"
+  },
   {
     "command": "external --iterations=2"
   },
@@ -47,6 +53,9 @@ CONBENCH_LIST = """
   },
   {
     "command": "matrix-types --all=true --iterations=2"
+  },
+  {
+    "command": "product --iterations=2"
   }
 ]
 """
@@ -71,7 +80,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
@@ -112,7 +124,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
@@ -145,7 +160,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
@@ -165,7 +183,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
@@ -179,7 +200,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
@@ -195,7 +219,10 @@ Options:
   --show-result BOOLEAN  [default: true]
   --show-output BOOLEAN  [default: false]
   --run-id TEXT          Group executions together with a run id.
-  --run-name TEXT        Name of run (commit, pull request, etc).
+  --run-name TEXT        Free-text name of run (commit ABC, pull request 123,
+                         etc).
+  --run-reason TEXT      Low-cardinality reason for run (commit, pull request,
+                         manual, etc).
   --help                 Show this message and exit.
 """
 
