@@ -2,19 +2,28 @@ import pytest
 
 from .. import create_application
 from ..config import TestConfig
-from ..db import Session, configure_engine, create_all, drop_all
+from ..db import Session, configure_engine, create_all, drop_all, empty_db_tables
 
 pytest.register_assert_rewrite("conbench.tests.api._asserts")
 pytest.register_assert_rewrite("conbench.tests.app._asserts")
 
 
-@pytest.fixture(autouse=True)
-def create_db():
+# Session-scope fixture, i.e. run this _once_ per test suite.
+@pytest.fixture(scope="session")
+def create_db_tables():
     configure_engine(TestConfig.SQLALCHEMY_DATABASE_URI)
     drop_all()
     create_all()
 
 
+# Run this once per test, i.e. this can get expensive and contribute
+# significantly to the duration of the test suite. `empty_db_tables()` is meant
+# to be faster than drop_all()/create_all().
+@pytest.fixture(autouse=True)
+def clear_db_state_between_tests():
+    empty_db_tables()
+
+
 @pytest.fixture
 def application():
     application = create_application(TestConfig)
@@ -36,29 +45,3 @@ def client(application):
 @pytest.fixture
 def runner(application):
     return application.test_cli_runner()
-
-
-def pytest_addoption(parser):
-    parser.addoption(
-        "--run-slow",
-        action="store_true",
-        default=False,
-        help="run slow tests",
-    )
-
-
-def pytest_configure(config):
-    config.addinivalue_line(
-        "markers",
-        "slow: mark test as slow to run",
-    )
-
-
-def pytest_collection_modifyitems(config, items):
-    if config.getoption("--run-slow"):
-        return
-    reason = "need --run-slow option to run"
-    skip_slow = pytest.mark.skip(reason=reason)
-    for item in items:
-        if "slow" in item.keywords:
-            item.add_marker(skip_slow)
